"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useDeviceOrientation = void 0;
var _react = require("react");
var _reactNative = require("react-native");
/**
 * A custom React hook for determining the device orientation.
 *
 * @returns {string} The current device orientation, either 'portrait' or 'landscape'.
 *
 * @example
 * // Import the hook
 * import { useDeviceOrientation } from './path-to-your-hook';
 *
 * // Use the hook in a component
 * const OrientationComponent = () => {
 *   const orientation = useDeviceOrientation();
 *
 *   useEffect(() => {
 *     console.log('Device Orientation:', orientation);
 *   }, [orientation]);
 *
 *   return (
 *     <View>
 *       <Text>Current Orientation: {orientation}</Text>
 *     </View>
 *   );
 * };
 */
const useDeviceOrientation = () => {
  const {
    width,
    height
  } = (0, _reactNative.useWindowDimensions)();
  const [orientation, setOrientation] = (0, _react.useState)(height > width ? 'portrait' : 'landscape');
  (0, _react.useEffect)(() => {
    setOrientation(height > width ? 'portrait' : 'landscape');
  }, [width, height]);
  return orientation;
};
exports.useDeviceOrientation = useDeviceOrientation;
//# sourceMappingURL=useDeviceOrientation.js.map