"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useFetch = void 0;
var _useAsync = require("./useAsync");
const DEFAULT_HEADERS = {
  'Content-Type': 'application/json'
};

/**
 * Hook to fetch data from an API
 * @param url fetch url
 * @param options fetch options
 * @returns Promise with the response body
 */
const useFetch = function (url) {
  let options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
  return (0, _useAsync.useAsync)(() => fetch(url, {
    ...options,
    headers: {
      ...DEFAULT_HEADERS,
      ...(options.headers ?? {})
    }
  }).then(res => {
    if (res.ok) {
      return res.json();
    }
    return res.json().then(json => {
      throw new Error(json);
    });
  }));
};
exports.useFetch = useFetch;
//# sourceMappingURL=useFetch.js.map