"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useStateWithValidation = void 0;
var _react = require("react");
var _useUpdateEffect = require("./useUpdateEffect");
/**
 * Extends React.useState with a validator function (second parameter) that validates the state and returns a boolean as a third value of the output array.
 * @param initialValue initial value of the state
 * @param validator function-validator that validates the state after each state update
 * @returns [state, setState, isValid] - state is the current state, setState is the setter for the state, isValid is a boolean that indicates if the state passes the validation
 */
const useStateWithValidation = (initialValue, validator) => {
  const [state, setState] = (0, _react.useState)(initialValue);
  const [isValid, setIsValid] = (0, _react.useState)(validator(state));
  (0, _useUpdateEffect.useUpdateEffect)(() => {
    setIsValid(validator(state));
  }, [state, validator]);
  return [state, setState, isValid];
};
exports.useStateWithValidation = useStateWithValidation;
//# sourceMappingURL=useStateWithValidation.js.map