import { useEffect, useState } from 'react';

/**
 * Async wrapper for async/await functions with Promise return
 * @param asyncFn should return promise
 * @returns data - expected value of "asyncFn", error - something went wrong (unexpected), loading - is asyncFn running
 */
export const useAsync = asyncFn => {
  const [data, setData] = useState(null);
  const [error, setError] = useState(null);
  const [isLoading, setIsLoading] = useState(false);
  useEffect(() => {
    setData(null);
    setError(null);
    setIsLoading(false);
    const fetchData = async () => {
      setIsLoading(true);
      try {
        const result = await asyncFn();
        setData(result);
      } catch (err) {
        setError(err);
      } finally {
        setIsLoading(false);
      }
    };
    fetchData();
  }, [asyncFn]);
  return {
    data,
    error,
    loading: isLoading
  };
};
//# sourceMappingURL=useAsync.js.map