import { useEffect, useState } from 'react';
import { useWindowDimensions } from 'react-native';
/**
 * A custom React hook for determining the device orientation.
 *
 * @returns {string} The current device orientation, either 'portrait' or 'landscape'.
 *
 * @example
 * // Import the hook
 * import { useDeviceOrientation } from './path-to-your-hook';
 *
 * // Use the hook in a component
 * const OrientationComponent = () => {
 *   const orientation = useDeviceOrientation();
 *
 *   useEffect(() => {
 *     console.log('Device Orientation:', orientation);
 *   }, [orientation]);
 *
 *   return (
 *     <View>
 *       <Text>Current Orientation: {orientation}</Text>
 *     </View>
 *   );
 * };
 */
export const useDeviceOrientation = () => {
  const {
    width,
    height
  } = useWindowDimensions();
  const [orientation, setOrientation] = useState(height > width ? 'portrait' : 'landscape');
  useEffect(() => {
    setOrientation(height > width ? 'portrait' : 'landscape');
  }, [width, height]);
  return orientation;
};
//# sourceMappingURL=useDeviceOrientation.js.map