type Orientation = 'portrait' | 'landscape';
/**
 * A custom React hook for determining the device orientation.
 *
 * @returns {string} The current device orientation, either 'portrait' or 'landscape'.
 *
 * @example
 * // Import the hook
 * import { useDeviceOrientation } from './path-to-your-hook';
 *
 * // Use the hook in a component
 * const OrientationComponent = () => {
 *   const orientation = useDeviceOrientation();
 *
 *   useEffect(() => {
 *     console.log('Device Orientation:', orientation);
 *   }, [orientation]);
 *
 *   return (
 *     <View>
 *       <Text>Current Orientation: {orientation}</Text>
 *     </View>
 *   );
 * };
 */
export declare const useDeviceOrientation: () => Orientation;
export {};
//# sourceMappingURL=useDeviceOrientation.d.ts.map